# Changelog

## v0.0.2
---
- Adds basic regressor, docs, and more [PR: 16](https://github.com/lazarust/sklx/pull/16) [@lazarust](https://github.com/lazarust/)
- Adds grid search support [PR: 13](https://github.com/lazarust/sklx/pull/13) [@lazarust](https://github.com/lazarust/)
- Adds `sklearn` Pipeline Support [PR: 4](https://github.com/lazarust/sklx/pull/4) [@lazarust](https://github.com/lazarust/)

## v0.0.1
---
- Adds basic classifier, docs, and more [PR: 2](https://github.com/lazarust/sklx/pull/2) [@lazarust](https://github.com/lazarust/)
